# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

__config__ = pulumi.Config('ns1')

apikey = __config__.get('apikey') or utilities.get_env('NS1_APIKEY')
"""
The ns1 API key, this is required
"""

enable_ddi = __config__.get('enableDdi')

endpoint = __config__.get('endpoint') or utilities.get_env('NS1_ENDPOINT')

ignore_ssl = __config__.get('ignoreSsl')

rate_limit_parallelism = __config__.get('rateLimitParallelism')

